# -*- coding: utf-8 -*-

#
# omdict - Ordered Multivalue Dictionary.
#
# Arthur Grunseid
# grunseid.com
# grunseid@gmail.com
#
# License: Build Amazing Things (Unlicense)

from __future__ import absolute_import

from .orderedmultidict import *  # noqa

__title__ = 'orderedmultidict'
__version__ = '0.7.11'
__author__ = 'Arthur Grunseid'
__contact__ = 'grunseid@gmail.com'
__license__ = 'Unlicense'
__url__ = 'https://github.com/gruns/orderedmultidict'
